<template>
  <j-modal
    :title="title"
    :width="800"
    :visible="visible"
    :confirmLoading="confirmLoading"
    switchFullscreen
    @ok="handleOk"
    @cancel="handleCancel"
    cancelText="关闭">

    <a-spin :spinning="confirmLoading">
      <a-form-model ref="form" :model="model" :rules="validatorRules">
        <a-form-model-item
          label="上传"
          :labelCol="labelCol"
          :wrapperCol="wrapperCol"
          v-if="!editable"
          prop="fileList">
          <lx-upload :returnUrl="false"
                     :isMultiple="false"
                     v-model="model.fileList"
                     biz="test">
          </lx-upload>
        </a-form-model-item>
        <a-form-model-item :labelCol="labelCol" :wrapperCol="wrapperCol" prop="fileName" label="文件名称" v-if="editable">
          <a-input placeholder="请输入文件名称" v-model="model.fileName" />
        </a-form-model-item>
        <a-form-model-item :labelCol="labelCol" :wrapperCol="wrapperCol" prop="description" label="描述">
          <a-textarea placeholder="请输入描述" v-model="model.description" />
        </a-form-model-item>
      </a-form-model>
    </a-spin>
  </j-modal>
</template>

<script>
import { httpAction } from '@/api/manage'

export default {
    name: "EamEquipmentAttachmentModal",
    props: {
      equipmentId: {
        type: String,
        required: false,
        default: '-1'
      }
    },
    data () {
      return {
        title:"操作",
        visible: false,
        model: {},
        labelCol: {
          xs: { span: 24 },
          sm: { span: 5 },
        },
        wrapperCol: {
          xs: { span: 24 },
          sm: { span: 16 },
        },

        confirmLoading: false,
        validatorRules:{
          fileName: [
            { required: true, message: '请输入文件名称!' }
          ]
        },
        url: {
          add: "/eam/equipmentAttachment/add",
          edit: "/eam/equipmentAttachment/edit",
        },
        editable: false,
      }
    },
    created () {
    },
    methods: {
      add () {
        this.editable = false;
        //初始化默认值
        this.model = {};
        this.visible = true
      },
      edit (record) {
        this.editable = true;
        this.model = Object.assign({}, record)
        this.visible = true
      },
      close () {
        this.$emit('close');
        this.visible = false;
        this.$refs.form.clearValidate();
      },
      handleOk () {
        const that = this;
        // 触发表单验证
         this.$refs.form.validate(valid => {
          if (valid) {
            that.confirmLoading = true;
            let httpurl = '';
            let method = '';
            if(!this.model.id){
              httpurl+=this.url.add;
              method = 'post';
            }else{
              httpurl+=this.url.edit;
               method = 'put';
            }
            that.model.equipmentId = that.equipmentId;
            httpAction(httpurl, that.model, method).then((res)=>{
              if(res.success){
                that.$message.success(res.message);
                that.$emit('ok');
                that.close();
              }else{
                that.$message.warning(res.message);
              }
            }).finally(() => {
              that.confirmLoading = false;
            })
          }else{
             return false;
          }
        })
      },
      handleCancel () {
        this.close()
      },


    }
  }
</script>

<style lang="less" scoped>

</style>